BigarrayElt

Trait BigarrayElt 

pub unsafe trait BigarrayElt: Copy {
    const KIND: i32;
}
Bigarray kind

Safety

This is unsafe to implement, because it allows casts to the implementing type (through OCaml<Array1<T>>::as_slice()).

To make this safe, the type implementing this trait must be safe to transmute from OCaml data with the relevant KIND.

Required Associated Constants

const KIND: i32

OCaml bigarray type identifier

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl BigarrayElt for char

Source

impl BigarrayElt for f32

Source

impl BigarrayElt for f64

Source

impl BigarrayElt for i8

Source

impl BigarrayElt for i16

Source

impl BigarrayElt for i32

Source

impl BigarrayElt for i64

Source

impl BigarrayElt for isize

Source

impl BigarrayElt for u8

Source

impl BigarrayElt for u16

Implementors