Type Definition ocaml_interop::OCamlRef [−][src]
type OCamlRef<'a, T> = &'a OCamlCell<T>;
An OCamlRef<T> is a reference to a location containing a OCaml<T> value.
Usually obtained as the result of rooting an OCaml value.